SystemOrganization addCategory: #ConfigurationOfSmaCC!

Object subclass: #ConfigurationOfSmaCC
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfSmaCC'!

!ConfigurationOfSmaCC commentStamp: '<historical>' prior: 0!
SmaCC is a parser generator, doing LR, LALR and GLR generation, parse tree automatic building, parse tree based rewritting (refactoring).

Copyright (c) 2014 Thierry Goubier
Copyright (c) 2002-2010 John Brant, Don Roberts

Permission is hereby granted, free of charge, to any person obtaining a copy 
of this software and associated documentation files (the "Software"), to deal 
in the Software without restriction, including without limitation the rights 
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
copies of the Software, and to permit persons to whom the Software is furnished 
to do so, subject to the following conditions:

The above copyright and this permission notice shall be included in all 
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS 
FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN 
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

!

!ConfigurationOfSmaCC class methodsFor: 'private' stamp: 'ThierryGoubier 1/28/2014 13:20:32'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfSmaCC class methodsFor: 'gitfiletree support' stamp: 'ThierryGoubier 2/3/2014 11:19'!
ensureGitFileTree
	"And all related dependencies."

	Smalltalk
		at: #MCFileTreeGitRepository
		ifAbsent: [ 
			Gofer new
				url: 'http://smalltalkhub.com/mc/Pharo/MetaRepoForPharo30/main';
				configurationOf: 'GitFileTree';
				loadDevelopment ]! !

!ConfigurationOfSmaCC class methodsFor: 'private' stamp: 'ThierryGoubier 1/28/2014 13:20:32'!
ensureMetacello
	"Bootstrap Gofer (if necessary), bootstrap ConfigurationOfMetacello (using old Gofer API), then load the latest 
	version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [
		Smalltalk at: #Gofer ifAbsent: [
			"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
			self bootstrapPackage: 'Gofer-Core-lr.115' from: 'http://seaside.gemstone.com/ss/metacello' ].
		Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
			gofer := goferClass new
				url: 'http://seaside.gemstone.com/ss/metacello';
				yourself.
			[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
			gofer load ].
		"load 'default' group of Metacello"
		(Smalltalk at: #ConfigurationOfMetacello) perform: #load ]! !

!ConfigurationOfSmaCC class methodsFor: 'metacello tool support' stamp: 'ThierryGoubier 1/28/2014 13:20:32'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfSmaCC class methodsFor: 'metacello tool support' stamp: 'ThierryGoubier 1/28/2014 13:20:32'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfSmaCC class methodsFor: 'loading' stamp: 'ThierryGoubier 1/28/2014 13:20:32'!
load
	"self load"

	^self project latestVersion load! !

!ConfigurationOfSmaCC class methodsFor: 'metacello tool support' stamp: 'ThierryGoubier 1/28/2014 13:20:32'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfSmaCC class methodsFor: 'accessing' stamp: 'ThierryGoubier 1/28/2014 13:20:32'!
project

	^self new project! !

!ConfigurationOfSmaCC class methodsFor: 'unloading Metacello' stamp: 'ThierryGoubier 1/28/2014 13:20:32'!
unloadMetacello

	Smalltalk at: #ConfigurationOfMetacello ifPresent: [:cls | cls unloadMetacello ]! !

!ConfigurationOfSmaCC methodsFor: 'baselines' stamp: 'ThierryGoubier 1/28/2014 13:20:32'!
baseline01: spec
	<version: '0.1-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/SmaccDevelopment'.

		spec
			package: 'SmaCC';
			package: 'SmaCCDev' with: [ spec requires: 'SmaCC' ].
		
		spec
			group: 'default' with: #('Runtime');
			group: 'Runtime' with: #('SmaCC');
			group: 'Tools' with: #('SmaCCDev')
	]! !

!ConfigurationOfSmaCC methodsFor: 'baselines' stamp: 'ThierryGoubier 1/28/2014 13:20:32'!
baseline20: spec
	<version: '2.0-baseline'>
	spec
		for: #common
		do: [ 
			spec blessing: #baseline.
			spec repository: 'http://smalltalkhub.com/mc/PharoExtras/Smacc/main'.
			spec
				package: 'SmaCC-Source-Editing';
				package: 'SmaCC-Runtime' with: [ spec requires: 'SmaCC-Source-Editing' ];
				package: 'SmaCC-GLR-Runtime' with: [ spec requires: 'SmaCC-Runtime' ];
				package: 'SmaCC-Development' with: [ spec requires: 'SmaCC-GLR-Runtime' ];
				package: 'SmaCC-Development-UI' with: [ spec requires: 'SmaCC-Development' ];
				package: 'SmaCC-Tests' with: [ spec requires: 'SmaCC-GLR-Runtime' ];
				package: 'SmaCC-Rewrite-Engine' with: [ spec requires: 'SmaCC-Runtime' ];
				package: 'SmaCC-Rewrite-Engine-Tests' with: [ spec requires: 'SmaCC-Rewrite-Engine' ];
				package: 'SmaCC-Server-Session';
				package: 'SmaCC-Rewrite-Server' with: [ spec requires: 'SmaCC-Server-Session' ];
				package: 'SmaCC-Rewrite-Server-Worker'
					with: [ 
							spec
								requires: 'SmaCC-Rewrite-Engine';
								requires: 'SmaCC-Server-Session' ];
				package: 'SmaCC-Smalltalk-Parser' with: [ spec requires: 'SmaCC-Runtime' ];
				package: 'SmaCC-C-Parser' with: [ spec requires: 'SmaCC-Runtime' ];
				package: 'SmaCC-CSharp' with: [ spec requires: 'SmaCC-GLR-Runtime' ];
				package: 'SmaCC-Java' with: [ spec requires: 'SmaCC-GLR-Runtime' ].
			spec
				group: 'default' with: #('Tools');
				group: 'Runtime' with: #('SmaCC-GLR-Runtime');
				group: 'Rewrite' with: #('SmaCC-Rewrite-Server-Worker' 'SmaCC-Rewrite-Server');
				group: 'Tools' with: #('SmaCC-Development-UI' 'Examples');
				group: 'Examples' with: #('SmaCC-Smalltalk-Parser' 'SmaCC-C-Parser' 'SmaCC-CSharp' 'SmaCC-Java') ]! !

!ConfigurationOfSmaCC methodsFor: 'symbolic versions' stamp: 'ThierryGoubier 2/3/2014 11:17'!
development: spec
	<symbolicVersion: #development>
	
	spec for: #common version: '0.1'.
	spec for: #'pharo1.4.x' version: '0.2'.
	spec for: #'pharo2.0.x' version: '0.3'.
	spec for: #'pharo3.x' version: '203'! !

!ConfigurationOfSmaCC methodsFor: 'accessing' stamp: 'ThierryGoubier 1/28/2014 13:20:32'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfSmaCC methodsFor: 'symbolic versions' stamp: 'ThierryGoubier 1/28/2014 13:20:32'!
stable: spec
	<symbolicVersion: #stable>
	
	spec for: #common version: '0.1'.
	spec for: #'pharo1.4.x' version: '0.2'.
	spec for: #'pharo2.0.x' version: '0.3'.
	spec for: #'pharo3.x' version: '0.4'! !

!ConfigurationOfSmaCC methodsFor: 'versions' stamp: 'ThierryGoubier 1/28/2014 13:20:32'!
version01: spec
	<version: '0.1' imports: #('0.1-baseline')>
	
	spec for: #common do: [
		spec
			blessing: #stable;
			author: 'topa';
			description: 'Make SmaCC available via Metacello'.
		spec
			package: 'SmaCC' with: 'SmaCC-lr.14';
			package: 'SmaCCDev' with: 'SmaCCDev-AlainPlantec.25'.
		
	]! !

!ConfigurationOfSmaCC methodsFor: 'versions' stamp: 'ThierryGoubier 1/28/2014 13:20:32'!
version02: spec
	<version: '0.2' imports: #('0.1-baseline')>
	
	spec for: #common do: [
		spec
			blessing: #stable;
			author: 'ThierryGoubier';
			description: 'SmaCC Smalltalk Compiler Compiler for Pharo 1.4'.
		spec
			package: 'SmaCC' with: 'SmaCC-lr.14';
			package: 'SmaCCDev' with: 'SmaCCDev-ThierryGoubier.31'.
		
	]! !

!ConfigurationOfSmaCC methodsFor: 'versions' stamp: 'ThierryGoubier 1/28/2014 13:20:32'!
version03: spec
	<version: '0.3' imports: #('0.1-baseline')>
	
	spec for: #common do: [
		spec
			blessing: #stable;
			author: 'ThierryGoubier';
			description: 'SmaCC Smalltalk Compiler Compiler for Pharo 2.0'.
		spec
			package: 'SmaCC' with: 'SmaCC-lr.14';
			package: 'SmaCCDev' with: 'SmaCCDev-ThierryGoubier.33'.
		
	]! !

!ConfigurationOfSmaCC methodsFor: 'versions' stamp: 'ThierryGoubier 1/28/2014 13:20:32'!
version04: spec
	<version: '0.4' imports: #('0.1-baseline')>
	
	spec for: #common do: [
		spec
			blessing: #stable;
			author: 'ThierryGoubier';
			description: 'SmaCC Smalltalk Compiler Compiler for Pharo 3.0'.
		spec
			package: 'SmaCC' with: 'SmaCC-lr.14';
			package: 'SmaCCDev' with: 'SmaCCDev-ThierryGoubier.36'.
		
	]! !

!ConfigurationOfSmaCC methodsFor: 'versions' stamp: 'ThierryGoubier 2/3/2014 11:20'!
version203: spec
	<version: '2.0.3' imports: #('2.0-baseline')>
	spec
		for: #common
		do: [ 
			self class ensureGitFileTree.
			spec
				blessing: #development;
				author: 'ThierryGoubier';
				description: 'SmaCC Smalltalk Compiler Compiler for Pharo 3.0' ]! !
